summaryrefslogtreecommitdiff
path: root/source3/include/nameserv.h
diff options
context:
space:
mode:
Diffstat (limited to 'source3/include/nameserv.h')
-rw-r--r--source3/include/nameserv.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/source3/include/nameserv.h b/source3/include/nameserv.h
index 25934c23f7..8882948ff4 100644
--- a/source3/include/nameserv.h
+++ b/source3/include/nameserv.h
@@ -144,17 +144,19 @@ struct work_record
uint32 ElectionCriterion;
};
-/* a domain structure. it contains a list of workgroups */
-struct domain_record
+/* a subnet structure. it contains a list of workgroups */
+struct subnet_record
{
- struct domain_record *next;
- struct domain_record *prev;
+ struct subnet_record *next;
+ struct subnet_record *prev;
struct work_record *workgrouplist;
struct in_addr bcast_ip;
struct in_addr mask_ip;
struct in_addr myip;
+
+ BOOL my_interface;
};
/* a resource record */